@@ -1,4 +1,6 @@
-#! perl
+#! /usr/bin/perl
+# PODNAME: tapper-automatic-test.pl
+# ABSTRACT: cmdline frontend to Testcontrol.autoinstall
 
 use strict;
 use warnings;
@@ -28,3 +30,27 @@ if (@ARGV and $ARGV[0] eq "autoinstall") {
 my $prc = new Tapper::PRC::Testcontrol;
 $prc->run();
 
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+tapper-automatic-test.pl - cmdline frontend to Testcontrol.autoinstall
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
